@@ -1,5 +1,8 @@
-from pydantic import BaseModel, Field
-from typing import Optional, List
+from typing import List, Optional
+
+from pydantic import BaseModel
+
+from ..base_model import BaseResponseModel
 
 
 class CustomerBillingConfiguration(BaseModel):
@@ -11,15 +14,18 @@ class CustomerBillingConfiguration(BaseModel):
     sync_with_provider: Optional[bool]
     document_locale: Optional[str]
 
+
 class Metadata(BaseModel):
     id: Optional[str]
     key: Optional[str]
     value: Optional[str]
     display_in_invoice: Optional[bool]
 
+
 class MetadataList(BaseModel):
     __root__: List[Metadata]
 
+
 class Customer(BaseModel):
     external_id: str
     address_line1: Optional[str]
@@ -41,7 +47,7 @@ class Customer(BaseModel):
     billing_configuration: Optional[CustomerBillingConfiguration]
 
 
-class CustomerResponse(BaseModel):
+class CustomerResponse(BaseResponseModel):
     lago_id: str
     external_id: str
     address_line1: Optional[str]
