@@ -1,5 +1,8 @@
-from pydantic import BaseModel, Field
-from typing import Optional
+from typing import Optional, List
+
+from pydantic import BaseModel
+
+from ..base_model import BaseResponseModel
 
 
 class OrganizationBillingConfiguration(BaseModel):
@@ -21,10 +24,11 @@ class Organization(BaseModel):
     legal_name: Optional[str]
     legal_number: Optional[str]
     timezone: Optional[str]
+    email_settings: Optional[List[str]]
     billing_configuration: Optional[OrganizationBillingConfiguration]
 
 
-class OrganizationResponse(BaseModel):
+class OrganizationResponse(BaseResponseModel):
     name: str
     created_at: str
     webhook_url: Optional[str]
@@ -38,4 +42,5 @@ class OrganizationResponse(BaseModel):
     legal_name: Optional[str]
     legal_number: Optional[str]
     timezone: Optional[str]
+    email_settings: Optional[List[str]]
     billing_configuration: Optional[OrganizationBillingConfiguration]
