@@ -1,19 +1,10 @@
-from pydantic import BaseModel, Field
-from typing import Optional, List, Union
+from typing import Optional
 
-class GroupProperties(BaseModel):
-    group_id: Optional[str]
-    values: Optional[dict]
+from pydantic import BaseModel
 
-class Charge(BaseModel):
-    id: Optional[str]
-    billable_metric_id: Optional[str]
-    charge_model: Optional[str]
-    properties: Optional[dict]
-    group_properties: Optional[GroupProperties]
+from .charge import Charges, ChargesResponse
+from ..base_model import BaseResponseModel
 
-class Charges(BaseModel):
-    __root__: List[Charge]
 
 class Plan(BaseModel):
     name: Optional[str]
@@ -28,7 +19,7 @@ class Plan(BaseModel):
     charges: Optional[Charges]
 
 
-class PlanResponse(BaseModel):
+class PlanResponse(BaseResponseModel):
     lago_id: str
     name: str
     created_at: str
@@ -40,6 +31,6 @@ class PlanResponse(BaseModel):
     trial_period: Optional[float]
     pay_in_advance: Optional[bool]
     bill_charges_monthly: Optional[bool]
-    charges: Optional[Charges]
+    charges: Optional[ChargesResponse]
     active_subscriptions_count: int
     draft_invoices_count: int
